@@ -1,5 +1,5 @@
 from logging import getLogger
-from typing import List, Optional, TYPE_CHECKING
+from typing import TYPE_CHECKING, List, Optional
 
 from pyknp import BList, Tag
 
